lists.arthurdejong.org
RSS feed

python-stdnum commit: r165 - in python-stdnum/stdnum: . at be bg br cy cz de dk ee es eu fi fr gb gr hr hu ie iso7064 it lt lu lv mt nl pl pt ro se si sk us

[Date Prev][Date Next] [Thread Prev][Thread Next]

python-stdnum commit: r165 - in python-stdnum/stdnum: . at be bg br cy cz de dk ee es eu fi fr gb gr hr hu ie iso7064 it lt lu lv mt nl pl pt ro se si sk us



Author: arthur
Date: Sun Feb 26 12:10:38 2012
New Revision: 165
URL: http://arthurdejong.org/viewvc/python-stdnum?revision=165&view=revision

Log:
ensure that the module docstrings are in a somewhat more usable format

Modified:
   python-stdnum/stdnum/__init__.py
   python-stdnum/stdnum/at/uid.py
   python-stdnum/stdnum/be/vat.py
   python-stdnum/stdnum/bg/egn.py
   python-stdnum/stdnum/bg/pnf.py
   python-stdnum/stdnum/bg/vat.py
   python-stdnum/stdnum/br/cpf.py
   python-stdnum/stdnum/cy/vat.py
   python-stdnum/stdnum/cz/dic.py
   python-stdnum/stdnum/cz/rc.py
   python-stdnum/stdnum/de/vat.py
   python-stdnum/stdnum/dk/cpr.py
   python-stdnum/stdnum/dk/cvr.py
   python-stdnum/stdnum/ean.py
   python-stdnum/stdnum/ee/kmkr.py
   python-stdnum/stdnum/es/cif.py
   python-stdnum/stdnum/es/dni.py
   python-stdnum/stdnum/es/nie.py
   python-stdnum/stdnum/es/nif.py
   python-stdnum/stdnum/eu/vat.py
   python-stdnum/stdnum/fi/alv.py
   python-stdnum/stdnum/fi/hetu.py
   python-stdnum/stdnum/fr/siren.py
   python-stdnum/stdnum/fr/tva.py
   python-stdnum/stdnum/gb/vat.py
   python-stdnum/stdnum/gr/vat.py
   python-stdnum/stdnum/grid.py
   python-stdnum/stdnum/hr/oib.py
   python-stdnum/stdnum/hu/anum.py
   python-stdnum/stdnum/iban.py
   python-stdnum/stdnum/ie/pps.py
   python-stdnum/stdnum/ie/vat.py
   python-stdnum/stdnum/imei.py
   python-stdnum/stdnum/imsi.py
   python-stdnum/stdnum/isan.py
   python-stdnum/stdnum/isbn.py
   python-stdnum/stdnum/isil.py
   python-stdnum/stdnum/ismn.py
   python-stdnum/stdnum/iso7064/__init__.py
   python-stdnum/stdnum/iso7064/mod_11_10.py
   python-stdnum/stdnum/iso7064/mod_11_2.py
   python-stdnum/stdnum/iso7064/mod_37_2.py
   python-stdnum/stdnum/iso7064/mod_37_36.py
   python-stdnum/stdnum/iso7064/mod_97_10.py
   python-stdnum/stdnum/issn.py
   python-stdnum/stdnum/it/iva.py
   python-stdnum/stdnum/lt/pvm.py
   python-stdnum/stdnum/lu/tva.py
   python-stdnum/stdnum/luhn.py
   python-stdnum/stdnum/lv/pvn.py
   python-stdnum/stdnum/meid.py
   python-stdnum/stdnum/mt/vat.py
   python-stdnum/stdnum/nl/bsn.py
   python-stdnum/stdnum/nl/btw.py
   python-stdnum/stdnum/nl/onderwijsnummer.py
   python-stdnum/stdnum/numdb.py
   python-stdnum/stdnum/pl/nip.py
   python-stdnum/stdnum/pt/nif.py
   python-stdnum/stdnum/ro/cf.py
   python-stdnum/stdnum/ro/cnp.py
   python-stdnum/stdnum/se/vat.py
   python-stdnum/stdnum/si/ddv.py
   python-stdnum/stdnum/sk/dph.py
   python-stdnum/stdnum/sk/rc.py
   python-stdnum/stdnum/us/ssn.py
   python-stdnum/stdnum/util.py
   python-stdnum/stdnum/verhoeff.py

Modified: python-stdnum/stdnum/__init__.py
==============================================================================
--- python-stdnum/stdnum/__init__.py    Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/__init__.py    Sun Feb 26 12:10:38 2012        (r165)
@@ -18,8 +18,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""A Python module to parse, validate and reformat standard numbers
-and codes in different formats.
+"""Parse, validate and reformat standard numbers and codes.
+
+This library offers functions for parsing, validating and reformatting
+standard numbers and codes in various formats.
 
 Currently this package supports the following formats:
 

Modified: python-stdnum/stdnum/at/uid.py
==============================================================================
--- python-stdnum/stdnum/at/uid.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/at/uid.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -17,10 +17,9 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Austrian UID (Umsatzsteuer-Identifikationsnummer,
-VAT) numbers.
+"""UID (Umsatzsteuer-Identifikationsnummer, Austrian VAT number).
 
-The number is a 9-digit number that always starts with a U (optionally
+The Austrian UID is a 9-digit number that starts with a U (optionally
 preceded with AT). The last digit is a check digit.
 
 >>> compact('AT U13585627')

Modified: python-stdnum/stdnum/be/vat.py
==============================================================================
--- python-stdnum/stdnum/be/vat.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/be/vat.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -17,7 +17,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Belgian VAT (BTW TVA NWSt) numbers.
+"""BTW, TVA, NWSt (Belgian VAT number).
 
 >>> compact('BE403019261')
 '0403019261'

Modified: python-stdnum/stdnum/bg/egn.py
==============================================================================
--- python-stdnum/stdnum/bg/egn.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/bg/egn.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,7 +18,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Bulgarian EGN (ЕГН, Единен граждански номер) numbers.
+"""EGN (ЕГН, Единен граждански номер, Bulgarian personal identity codes).
 
 It is a 10-digit number of which the first 6 digits denote the person's
 birth date, the next three digits represent a birth order number from

Modified: python-stdnum/stdnum/bg/pnf.py
==============================================================================
--- python-stdnum/stdnum/bg/pnf.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/bg/pnf.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,7 +18,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Bulgarian PNF (ЛНЧ, Личен номер на чужденец) numbers.
+"""PNF (ЛНЧ, Личен номер на чужденец, Bulgarian number of a foreigner).
 
 The personal number of a foreigner is a 10-digit number where the last digit
 is the result of a weighted checksum.

Modified: python-stdnum/stdnum/bg/vat.py
==============================================================================
--- python-stdnum/stdnum/bg/vat.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/bg/vat.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,7 +18,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Bulgarian VAT (Идентификационен номер по ДДС) numbers.
+"""VAT (Идентификационен номер по ДДС, Bulgarian VAT number).
 
 The Bulgarian VAT (Данък върху добавената стойност) number is either 9
 (for legal entities) or 10 digits (for physical persons, foreigners and

Modified: python-stdnum/stdnum/br/cpf.py
==============================================================================
--- python-stdnum/stdnum/br/cpf.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/br/cpf.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,8 +18,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling CPF (Cadastro de Pessoas Físicas) numbers, the
-Brazillian national identification number.
+"""CPF (Cadastro de Pessoas Físicas, Brazillian national identifier).
 
 >>> is_valid('390.533.447-05')
 True

Modified: python-stdnum/stdnum/cy/vat.py
==============================================================================
--- python-stdnum/stdnum/cy/vat.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/cy/vat.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,10 +18,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Cypriot Αριθμός Εγγραφής Φ.Π.Α. (VAT) numbers.
+"""Αριθμός Εγγραφής Φ.Π.Α. (Cypriot VAT number).
 
-The number consists of 9 digits where the last one is a is a letter and
-functions as a check digit.
+The Cypriot Αριθμός Εγγραφής Φ.Π.Α. (VAT) number consists of 9 digits
+where the last one is a is a letter and functions as a check digit.
 
 >>> compact('CY-10259033P')
 '10259033P'

Modified: python-stdnum/stdnum/cz/dic.py
==============================================================================
--- python-stdnum/stdnum/cz/dic.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/cz/dic.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,12 +18,12 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Czech DIČ (Daňové identifikační číslo, VAT) numbers.
+"""DIČ (Daňové identifikační číslo, Czech VAT number).
 
-It is an 8, 9 or 10 digit code that includes a check digit and is used to
-uniquely identify taxpayers for VAT (DPH in Czech). The number can refer
-to legal entities (8 digit numbers), individuals with a RČ (the 9 or 10
-digit Czech birth number) or individuals without a RČ (9 digit numbers
+The number is an 8, 9 or 10 digit code that includes a check digit and is
+used to uniquely identify taxpayers for VAT (DPH in Czech). The number can
+refer to legal entities (8 digit numbers), individuals with a RČ (the 9 or
+10 digit Czech birth number) or individuals without a RČ (9 digit numbers
 that begin with a 6).
 
 >>> compact('CZ 25123891')

Modified: python-stdnum/stdnum/cz/rc.py
==============================================================================
--- python-stdnum/stdnum/cz/rc.py       Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/cz/rc.py       Sun Feb 26 12:10:38 2012        (r165)
@@ -18,10 +18,14 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Czech birth numbers (RČ, Rodné číslo), the Czech
-national identifier. The number can be 9 or 10 digits long. Numbers given
-out after January 1st 1954 should have 10 digits. The number includes the
-birth date of the person and their gender.
+"""RČ (Rodné číslo, the Czech birth number).
+
+The birth number (RČ, Rodné číslo) is the Czech national identifier. The
+number can be 9 or 10 digits long. Numbers given out after January 1st
+1954 should have 10 digits. The number includes the birth date of the
+person and their gender.
+
+This number is identical to the Slovak counterpart.
 
 >>> compact('710319/2745')
 '7103192745'

Modified: python-stdnum/stdnum/de/vat.py
==============================================================================
--- python-stdnum/stdnum/de/vat.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/de/vat.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -17,9 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
+"""Ust ID Nr. (Umsatzsteur Identifikationnummer, the German VAT number).
 
-"""Module for handling German VAT (Umsatzsteur Identifikationnummer, Ust
-ID Nr.) numbers.
+The number is 10 digits long and uses the ISO 7064 Mod 11, 10 check digit
+algorithm.
 
 >>> compact('DE 136,695 976')
 '136695976'

Modified: python-stdnum/stdnum/dk/cpr.py
==============================================================================
--- python-stdnum/stdnum/dk/cpr.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/dk/cpr.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -17,11 +17,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Danish CPR-number (or personnummer, the Danish
-citizen number).
+"""CPR (personnummer, the Danish citizen number).
 
-The number consists of 10 digits in the format DDMMYY-SSSS where the first
-part represents the birth date and the second a sequence number. The first
+The CPR is the national number to identify Danish citizens. The number
+consists of 10 digits in the format DDMMYY-SSSS where the first part
+represents the birth date and the second a sequence number. The first
 digit of the sequence number indicates the century.
 
 The numbers used to validate using a checksum but since the sequence
@@ -56,7 +56,7 @@
 
 def checksum(number):
     """Calculate the checksum. Note that the checksum isn't actually used
-    any more."""
+    any more. Valid numbers used to have a checksum of 0."""
     weights = (4, 3, 2, 7, 6, 5, 4, 3, 2, 1)
     return sum(weights[i] * int(n) for i, n in enumerate(number)) % 11
 

Modified: python-stdnum/stdnum/dk/cvr.py
==============================================================================
--- python-stdnum/stdnum/dk/cvr.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/dk/cvr.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -17,10 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
+"""CVR (Momsregistreringsnummer, Danish VAT number).
 
-"""Module for handling Danish CVR (Momsregistreringsnummer, VAT) numbers.
-
-It is an 8 digit number with a straightforward check mechanism.
+The CVR (Momsregistreringsnummer, VAT) is an 8 digit number with a
+straightforward check mechanism.
 
 >>> compact('DK 13585628')
 '13585628'

Modified: python-stdnum/stdnum/ean.py
==============================================================================
--- python-stdnum/stdnum/ean.py Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/ean.py Sun Feb 26 12:10:38 2012        (r165)
@@ -17,7 +17,9 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling EAN (International Article Number) codes. This
+"""EAN (International Article Number).
+
+Module for handling EAN (International Article Number) codes. This
 module handles numbers EAN-13, EAN-8 and UPC (12-digit) format.
 
 >>> is_valid('73513537')

Modified: python-stdnum/stdnum/ee/kmkr.py
==============================================================================
--- python-stdnum/stdnum/ee/kmkr.py     Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/ee/kmkr.py     Sun Feb 26 12:10:38 2012        (r165)
@@ -18,7 +18,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Estonian KMKR (Käibemaksukohuslase, VAT) numbers.
+"""KMKR (Käibemaksukohuslase, Estonian VAT number).
 
 >>> compact('EE 100 931 558')
 '100931558'

Modified: python-stdnum/stdnum/es/cif.py
==============================================================================
--- python-stdnum/stdnum/es/cif.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/es/cif.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,8 +18,9 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Spanish tax identification number (Certificado de
-Identificación Fiscal) for legal entities. The CIF is a 9 digit number
+"""CIF (Certificado de Identificación Fiscal, Spanish company tax number).
+
+The CIF is a tax identification number for legal entities. It has 9 digits
 where the first digit is a letter (denoting the type of entity) and the
 last is a check digit (which may also be a letter).
 

Modified: python-stdnum/stdnum/es/dni.py
==============================================================================
--- python-stdnum/stdnum/es/dni.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/es/dni.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,9 +18,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Spanish personal identity codes (DNI, Documento
-nacional de identidad). The DNI is a 9 digit number where the last digit is
-a checksum letter.
+"""DNI (Documento nacional de identidad, Spanish personal identity codes).
+
+The DNI is a 9 digit number used to identify Spanish citizens. The last
+digit is a checksum letter.
 
 Foreign nationals, since 2010 are issued an NIE (Número de Identificación
 de Extranjeros, Foreigner's Identity Number) instead.

Modified: python-stdnum/stdnum/es/nie.py
==============================================================================
--- python-stdnum/stdnum/es/nie.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/es/nie.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,8 +18,9 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Spanish tax identification number (Número de
-Identificación de Extranjeros) for foreigners. The NIE is a 9 digit number
+"""NIE (Número de Identificación de Extranjeros, Spanish foreigner number).
+
+The NIE is an identification number for foreigners. It is a 9 digit number
 where the first digit is either X, Y or Z and last digit is a checksum
 letter.
 

Modified: python-stdnum/stdnum/es/nif.py
==============================================================================
--- python-stdnum/stdnum/es/nif.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/es/nif.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,9 +18,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Spanish VAT (NIF, Número de Identificación Fiscal)
-numbers. It is a 9 digit number where either the first, last digits or
-both can be letters.
+"""NIF (Número de Identificación Fiscal, Spanish VAT number).
+
+The Spanish VAT number is a 9-digit number where either the first, last
+digits or both can be letters.
 
 The number is either a DNI (Documento nacional de identidad, for
 Spaniards), a NIE (Número de Identificación de Extranjeros, for

Modified: python-stdnum/stdnum/eu/vat.py
==============================================================================
--- python-stdnum/stdnum/eu/vat.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/eu/vat.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,7 +18,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling various European VAT numbers.
+"""VAT (European Union VAT number).
+
+The European Union VAT number consists of a 2 letter country code (ISO
+3166-1, except Greece which uses EL) followed by a number that is
+allocated per country. The format varies per country.
 
 >>> is_valid('ATU 57194903')
 True

Modified: python-stdnum/stdnum/fi/alv.py
==============================================================================
--- python-stdnum/stdnum/fi/alv.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/fi/alv.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,7 +18,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Finnish ALV nro (Arvonlisäveronumero, VAT) numbers.
+"""ALV nro (Arvonlisäveronumero, Finnish VAT number).
 
 The number is an 8-digit code with a weighted checksum.
 

Modified: python-stdnum/stdnum/fi/hetu.py
==============================================================================
--- python-stdnum/stdnum/fi/hetu.py     Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/fi/hetu.py     Sun Feb 26 12:10:38 2012        (r165)
@@ -18,8 +18,9 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Finnish personal identity codes (HETU, Henkilötunnus).
+"""HETU (Henkilötunnus, Finnish personal identity code).
 
+Module for handling Finnish personal identity codes (HETU, Henkilötunnus).
 See http://www.vaestorekisterikeskus.fi/default.aspx?id=45 for checksum
 calculation details and http://tarkistusmerkit.teppovuori.fi/tarkmerk.htm#hetu1
 for historical details.

Modified: python-stdnum/stdnum/fr/siren.py
==============================================================================
--- python-stdnum/stdnum/fr/tva.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/fr/tva.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,12 +18,12 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling French TVA (Numéro d'identification à la taxe sur
-la valeur ajoutée, VAT) numbers.
+"""n° TVA (taxe sur la valeur ajoutée, French VAT number).
 
-The number is the SIREN (Système d’Identification du Répertoire des
-Entreprises) prefixed by two digits. In old style numbers the two digits
-are numeric, with new style numbers at least one is a alphabetic.
+The n° TVA (Numéro d'identification à la taxe sur la valeur ajoutée) is the
+SIREN (Système d’Identification du Répertoire des Entreprises) prefixed by
+two digits. In old style numbers the two digits are numeric, with new
+style numbers at least one is a alphabetic.
 
 >>> compact('Fr 40 303 265 045')
 '40303265045'

Modified: python-stdnum/stdnum/gb/vat.py
==============================================================================
--- python-stdnum/stdnum/gb/vat.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/gb/vat.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -17,13 +17,12 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling United Kingdom (and Isle of Man) VAT registration
-numbers.
+"""VAT (United Kingdom (and Isle of Man) VAT registration number).
 
-The number can either be a 9-digit standard number, a 12-digit standard
-number followed by a 3-digit branch identifyier, a 5-digit number for
+The VAT number can either be a 9-digit standard number, a 12-digit standard
+number followed by a 3-digit branch identifier, a 5-digit number for
 government departments (first two digits are GD) or a 5-digit number for
-health authorities (first two digits are HA). The 9-digit part contains a
+health authorities (first two digits are HA). The 9-digit variants use a
 weighted checksum.
 
 >>> compact('GB 980 7806 84')

Modified: python-stdnum/stdnum/gr/vat.py
==============================================================================
--- python-stdnum/stdnum/grid.py        Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/grid.py        Sun Feb 26 12:10:38 2012        (r165)
@@ -17,8 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling GRid (Global Release Identifier) numbers, used to
-identify releases of digital sound recordings.
+"""GRid (Global Release Identifier).
+
+The GRid (Global Release Identifier) is used to identify releases of
+digital sound recordings.
 
 >>> is_valid('A12425GABC1234002M')
 True

Modified: python-stdnum/stdnum/hr/oib.py
==============================================================================
--- python-stdnum/stdnum/hr/oib.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/hr/oib.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,12 +18,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Croatian OIB numbers (Osobni identifikacijski broj,
-personal identification number).
+"""OIB (Osobni identifikacijski broj, Croatian identification number).
 
-The number is used to identify persons and legal entities and has 11
-digits (sometimes prefixed by HR), contains no personal information and
-uses the ISO 7064 Mod 11, 10 checksum algorithm.
+The personal identification number is used to identify persons and legal
+entities and has 11 digits (sometimes prefixed by HR), contains no
+personal information and uses the ISO 7064 Mod 11, 10 checksum algorithm.
 
 >>> compact('HR 33392005961')
 '33392005961'

Modified: python-stdnum/stdnum/hu/anum.py
==============================================================================
--- python-stdnum/stdnum/hu/anum.py     Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/hu/anum.py     Sun Feb 26 12:10:38 2012        (r165)
@@ -18,10 +18,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Hungarian ANUM (Közösségi adószám, VAT) numbers.
+"""ANUM (Közösségi adószám, Hungarian VAT number).
 
-It is an 8-digit taxpayer registration number that includes a weighted
-checksum.
+The ANUM is the Hungarian VAT (Közösségi adószám) number. It is an 8-digit
+taxpayer registration number that includes a weighted checksum.
 
 >>> compact('HU-12892312')
 '12892312'

Modified: python-stdnum/stdnum/iban.py
==============================================================================
--- python-stdnum/stdnum/iban.py        Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/iban.py        Sun Feb 26 12:10:38 2012        (r165)
@@ -17,9 +17,9 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling IBANs (International Bank Account Numbers)
-numbers, used to identify bank accounts across national borders.
+"""IBAN (International Bank Account Number).
 
+The IBAN is used to identify bank accounts across national borders.
 
 >>> is_valid('GR16 0110 1050 0000 1054 7023 795')
 True

Modified: python-stdnum/stdnum/ie/pps.py
==============================================================================
--- python-stdnum/stdnum/ie/pps.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/ie/pps.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -17,12 +17,12 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Irish PPS (Personal Public Service) numbers.
+"""PPS No (Personal Public Service Number, Irish personal number).
 
-The number consists of 8 digits. The first seven are numeric and the last
-is the check character. The number is sometimes be followed by an extra
-letter, which is ignored for the check algorithm, and can be a 'W', 'T' or
-an 'X'.
+The PPS (Personal Public Service) number consists of 8 digits. The first
+seven are numeric and the last is the check character. The number is
+sometimes be followed by an extra letter, which is ignored for the check
+algorithm, and can be a 'W', 'T' or an 'X'.
 
 >>> compact('6433435F')
 '6433435F'

Modified: python-stdnum/stdnum/ie/vat.py
==============================================================================
--- python-stdnum/stdnum/ie/vat.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/ie/vat.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -17,10 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Irish VAT numbers.
+"""VAT (Irish VAT number).
 
-The number consists of 8 digits. The last digit is a check letter, the
-second may be a number, letter, "+" or "*".
+The Irish VAT number consists of 8 digits. The last digit is a check
+letter, the second may be a number, letter, "+" or "*".
 
 >>> compact('IE 6433435F')
 '6433435F'

Modified: python-stdnum/stdnum/imei.py
==============================================================================
--- python-stdnum/stdnum/imei.py        Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/imei.py        Sun Feb 26 12:10:38 2012        (r165)
@@ -18,8 +18,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling IMEI (International Mobile Equipment Identity)
-numbers, used to identify mobile phones.
+"""IMEI (International Mobile Equipment Identity).
+
+The  IMEI (International Mobile Equipment Identity) is used to identify
+mobile phones.
 
 >>> is_valid('35686800-004141-20')
 True

Modified: python-stdnum/stdnum/imsi.py
==============================================================================
--- python-stdnum/stdnum/imsi.py        Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/imsi.py        Sun Feb 26 12:10:38 2012        (r165)
@@ -18,8 +18,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling IMSI (International Mobile Subscriber Identity)
-numbers, used to identify mobile phone users (the SIM).
+"""IMSI (International Mobile Subscriber Identity).
+
+The IMSI (International Mobile Subscriber Identity) is used to identify
+mobile phone users (the SIM).
 
 >>> is_valid('429011234567890')
 True

Modified: python-stdnum/stdnum/isan.py
==============================================================================
--- python-stdnum/stdnum/isan.py        Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/isan.py        Sun Feb 26 12:10:38 2012        (r165)
@@ -18,8 +18,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling ISANs (International Standard Audiovisual Numbers),
-used to identify audiovisual works.
+"""ISAN (International Standard Audiovisual Number).
+
+The ISAN (International Standard Audiovisual Number) is used to identify
+audiovisual works.
 
 >>> is_valid('000000018947000000000000')
 True

Modified: python-stdnum/stdnum/isbn.py
==============================================================================
--- python-stdnum/stdnum/isbn.py        Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/isbn.py        Sun Feb 26 12:10:38 2012        (r165)
@@ -17,9 +17,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling ISBNs (International Standard Book Number). This
-module handles both numbers in ISBN-10 (10-digit) and ISBN-13 (13-digit)
-format.
+"""ISBN (International Standard Book Number).
+
+The ISBN is the International Standard Book Number, used to identify
+publications. This module supports both numbers in ISBN-10 (10-digit) and
+ISBN-13 (13-digit) format.
 
 >>> is_valid('978-9024538270')
 True
@@ -85,8 +87,6 @@
         if ean.calc_check_digit(number[:-1]) != number[-1]:
             return None
         return 'ISBN13'
-    else:
-        return None
 
 
 def is_valid(number):
@@ -115,7 +115,7 @@
 
 
 def to_isbn10(number):
-    """Convert the number to ISBN-13 format."""
+    """Convert the number to ISBN-10 format."""
     number = number.strip()
     min_number = compact(number)
     if len(min_number) == 10:

Modified: python-stdnum/stdnum/isil.py
==============================================================================
--- python-stdnum/stdnum/isil.py        Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/isil.py        Sun Feb 26 12:10:38 2012        (r165)
@@ -18,8 +18,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling ISIL (International Standard Identifier for
-Libraries and Related Organizations).
+"""ISIL (International Standard Identifier for Libraries).
+
+The ISIL is the International Standard Identifier for
+Libraries and Related Organizations.
 
 >>> is_valid('IT-RM0267')
 True

Modified: python-stdnum/stdnum/ismn.py
==============================================================================
--- python-stdnum/stdnum/it/iva.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/it/iva.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -17,15 +17,14 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Italian IVA (Partita IVA (Imposta sul valore
-aggiunto), VAT) numbers.
+"""Partita IVA (Italian VAT number).
 
-The number consists of 11 digits. The first 7 digits are a company
-identifier, tge next 3 refer to the province of residence and the last is
-a check digit.
+The Partita IVA (Imposta sul valore aggiunto) consists of 11 digits. The
+first 7 digits are a company identifier, the next 3 refer to the province
+of residence and the last is a check digit.
 
-Note that the fiscal code for individuals is not accepted as valid code
-for intracommunity VAT related operations so it is ignored here.
+The fiscal code for individuals is not accepted as valid code for
+intracommunity VAT related operations so it is ignored here.
 
 >>> compact('IT 00743110157')
 '00743110157'

Modified: python-stdnum/stdnum/lt/pvm.py
==============================================================================
--- python-stdnum/stdnum/lt/pvm.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/lt/pvm.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,12 +18,12 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Lithuanian PVM (Pridėtinės vertės mokestis mokėtojo
-kodas, VAT) numbers.
+"""PVM (Pridėtinės vertės mokestis mokėtojo kodas, Lithuanian VAT number).
 
-The number is 9 (for legal entities) or 12 digits long (for temporarily
-registered taxpayers). This module does not check the format of Lithuanian
-personal codes (Asmens kodas).
+The PVM (Pridėtinės vertės mokestis mokėtojo kodas) is used for VAT
+purposes in Lithuania. Itis 9 digits (for legal entities) or 12 digits
+long (for temporarily registered taxpayers). This module does not check
+the format of Lithuanian personal codes (Asmens kodas).
 
 >>> compact('LT 100001919017')
 '100001919017'

Modified: python-stdnum/stdnum/lu/tva.py
==============================================================================
--- python-stdnum/stdnum/lu/tva.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/lu/tva.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,10 +18,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Luxembourgian No. TVA (Numéro d'identification à la
-taxe sur la valeur ajoutée, VAT) numbers.
+"""TVA (taxe sur la valeur ajoutée, Luxembourgian VAT number).
 
-The number consists of 8 digits of which the last two are check digits.
+The n° TVA (Numéro d'identification à la taxe sur la valeur ajoutée) is
+used for tax purposes in Luxembourg. The number consists of 8 digits of
+which the last two are check digits.
 
 >>> compact('LU 150 274 42')
 '15027442'

Modified: python-stdnum/stdnum/luhn.py
==============================================================================
--- python-stdnum/stdnum/luhn.py        Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/luhn.py        Sun Feb 26 12:10:38 2012        (r165)
@@ -17,12 +17,14 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for calculation and verifying the checksum of a number
-using the Luhn algorithm.
+"""The Luhn and Luhn mod N algorithms.
 
-Validation can be done with is_valid() which validates that the
-calculated checksum is 0. A valid number can be made by calculating
-the check digit and appending it.
+The Luhn algorithm to detect most accidental errors in various
+identification numbers.
+
+Validation can be done with is_valid() which validates that the calculated
+checksum is 0. A valid number can be made by calculating the check digit
+and appending it.
 
 >>> is_valid('7894')
 False
@@ -40,7 +42,6 @@
 False
 >>> checksum('1234', alphabet='0123456789abcdef')
 14
-
 """
 
 

Modified: python-stdnum/stdnum/lv/pvn.py
==============================================================================
--- python-stdnum/stdnum/lv/pvn.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/lv/pvn.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,13 +18,12 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Latvian PVN (Pievienotās vērtības nodokļa, VAT)
-numbers.
+"""PVN (Pievienotās vērtības nodokļa, Latvian VAT number).
 
-It is a 11 digit number that can either be a reference to a legal entity
-(in which case the first digit > 3) or a natural person (in which case it
-should be the same as the personal code (personas kods)). Personal codes
-start with 6 digits to denote the birth date in the form ddmmyy.
+The PVN is a 11-digit number that can either be a reference to a legal
+entity (in which case the first digit > 3) or a natural person (in which
+case it should be the same as the personal code (personas kods)). Personal
+codes start with 6 digits to denote the birth date in the form ddmmyy.
 
 >>> compact('LV 4000 3521 600')
 '40003521600'

Modified: python-stdnum/stdnum/meid.py
==============================================================================
--- python-stdnum/stdnum/meid.py        Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/meid.py        Sun Feb 26 12:10:38 2012        (r165)
@@ -17,17 +17,19 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling MEID (Mobile Equipment Identifier) numbers, used
-to identify physical piece of CDMA mobile station equipment.
+"""MEID (Mobile Equipment Identifier).
 
+The MEID (Mobile Equipment Identifier) is used to identify a physical piece
+of CDMA mobile station equipment.
+
+>>> compact('AF 01 23 45 0A BC DE C')
+'AF0123450ABCDE'
 >>> is_valid('AF 01 23 45 0A BC DE')
 True
 >>> is_valid('AF 01 23 45 0A BC DE C')
 True
 >>> is_valid('29360 87365 0070 3710 0')
 True
->>> compact('AF 01 23 45 0A BC DE C')
-'AF0123450ABCDE'
 >>> format('af0123450abcDEC', add_check_digit=True)
 'AF 01 23 45 0A BC DE C'
 """

Modified: python-stdnum/stdnum/mt/vat.py
==============================================================================
--- python-stdnum/stdnum/mt/vat.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/mt/vat.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -17,7 +17,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Maltese VAT numbers.
+"""VAT (Maltese VAT number).
 
 The Maltese VAT registration number contains 8 digits and uses a simple
 weigted checksum.

Modified: python-stdnum/stdnum/nl/bsn.py
==============================================================================
--- python-stdnum/stdnum/nl/bsn.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/nl/bsn.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -17,8 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling BSNs (Burgerservicenummer), the
-Dutch national identification number.
+"""BSN (Burgerservicenummer, the Dutch national identification number).
+
+The BSN is a number with up to 9 digits (the leading 0's are commonly left
+out) which is used as the Dutch national identification number.
 
 >>> is_valid('111222333')
 True
@@ -42,9 +44,10 @@
 
 
 def checksum(number):
-    """Calculate the checksum over the number."""
-    return (sum((9 - i) * int(number[i]) for i in range(8)) -
-            int(number[8])) % 11
+    """Calculate the checksum over the number. A valid number should have
+    a check digit of 0."""
+    return (sum((9 - i) * int(n) for i, n in enumerate(number[:-1])) -
+            int(number[-1])) % 11
 
 
 def is_valid(number):
@@ -54,10 +57,8 @@
         number = compact(number)
     except:
         return False
-    return len(number) == 9 and \
-           number.isdigit() and \
-           int(number) > 0 and \
-           checksum(number) == 0
+    return len(number) == 9 and number.isdigit() and \
+           int(number) > 0 and checksum(number) == 0
 
 
 def format(number):

Modified: python-stdnum/stdnum/nl/btw.py
==============================================================================
--- python-stdnum/stdnum/numdb.py       Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/numdb.py       Sun Feb 26 12:10:38 2012        (r165)
@@ -18,8 +18,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""This module contains functions for reading and querying a database for
-storing numbers that use a hierarchical format (e.g. ISBN, IBAN, phone
+"""Query structured number format files with number properties.
+
+This module contains functions for reading and querying a database that
+stores numbers that use a hierarchical format (e.g. ISBN, IBAN, phone
 numbers, etc).
 
 To read a database from a file:

Modified: python-stdnum/stdnum/pl/nip.py
==============================================================================
--- python-stdnum/stdnum/pl/nip.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/pl/nip.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -17,10 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Polish NIP (Numer Identyfikacji Podatkowej, VAT)
-numbers.
+"""NIP (Numer Identyfikacji Podatkowej, Polish VAT number).
 
-The number consists of 10 digit with a straightforward weighted checksum.
+The NIP (Numer Identyfikacji Podatkowej) number consists of 10 digit with
+a straightforward weighted checksum.
 
 >>> compact('PL 8567346215')
 '8567346215'

Modified: python-stdnum/stdnum/pt/nif.py
==============================================================================
--- python-stdnum/stdnum/ro/cnp.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/ro/cnp.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,11 +18,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Romanian CNP (Cod Numeric Personal, Numerical
-Personal Code) numbers.
+"""CNP (Cod Numeric Personal, Romanian Numerical Personal Code).
 
-It is a 13 digit number that includes information on the person's gender,
-birth date and country zone.
+The CNP is a 13 digit number that includes information on the person's
+gender, birth date and country zone.
 
 >>> compact('1630615123457')
 '1630615123457'

Modified: python-stdnum/stdnum/se/vat.py
==============================================================================
--- python-stdnum/stdnum/se/vat.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/se/vat.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,10 +18,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Swedish VAT (Moms, Mervärdesskatt) numbers.
+"""VAT (Moms, Mervärdesskatt, Swedish VAT number).
 
-The Momsregistreringsnummer consists of 12 digits of which the last two
-should be 01. The first 10 digits should have a valid Luhn checksum.
+The Momsregistreringsnummer is used for VAT (Moms, Mervärdesskatt)
+purposes and consists of 12 digits of which the last two should be 01. The
+first 10 digits should have a valid Luhn checksum.
 
 >>> compact('SE 123456789701')
 '123456789701'

Modified: python-stdnum/stdnum/si/ddv.py
==============================================================================
--- python-stdnum/stdnum/si/ddv.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/si/ddv.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,8 +18,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Slovenian ID za DDV (Davčna številka, Davek na
-dodano vrednost, VAT) numbers.
+"""ID za DDV (Davčna številka, Slovenian VAT number).
 
 The DDV number (Davčna številka) is used for VAT (DDV, Davek na dodano
 vrednost) purposes and consist of 8 digits of which the last is a check

Modified: python-stdnum/stdnum/sk/dph.py
==============================================================================
--- python-stdnum/stdnum/sk/dph.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/sk/dph.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,11 +18,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Slovak IČ DPH (Identifikačné číslo pre daň z
-pridanej hodnoty, VAT) numbers.
+"""IČ DPH (IČ pre daň z pridanej hodnoty, Slovak VAT number).
 
-The DPH is a 10-digit number used for VAT purposes. It has a
-straightforward checksum.
+The IČ DPH (Identifikačné číslo pre daň z pridanej hodnoty) is a 10-digit
+number used for VAT purposes. It has a straightforward checksum.
 
 >>> compact('SK 202 274 96 19')
 '2022749619'

Modified: python-stdnum/stdnum/sk/rc.py
==============================================================================
--- python-stdnum/stdnum/sk/rc.py       Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/sk/rc.py       Sun Feb 26 12:10:38 2012        (r165)
@@ -18,10 +18,14 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Slovak birth numbers (RČ, Rodné číslo), the Slovak
-national identifier. The number can be 9 or 10 digits long. Numbers given
-out after January 1st 1954 should have 10 digits. The number includes the
-birth date of the person and their gender.
+"""RČ (Rodné číslo, the Slovak birth number).
+
+The birth number (RČ, Rodné číslo) is the Slovak national identifier. The
+number can be 9 or 10 digits long. Numbers given out after January 1st
+1954 should have 10 digits. The number includes the birth date of the
+person and their gender.
+
+This number is identical to the Czech counterpart.
 
 >>> compact('710319/2745')
 '7103192745'

Modified: python-stdnum/stdnum/us/ssn.py
==============================================================================
--- python-stdnum/stdnum/us/ssn.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/us/ssn.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -17,8 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling U.S. Social Security Numbers (SSN), the number
-to identify individuals for taxation purposes.
+"""SSN (U.S. Social Security Number).
+
+The Social Security Number is used to identify individuals for taxation
+purposes.
 
 >>> is_valid('111-22-3333')
 True

Modified: python-stdnum/stdnum/util.py
==============================================================================
--- python-stdnum/stdnum/util.py        Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/util.py        Sun Feb 26 12:10:38 2012        (r165)
@@ -17,7 +17,12 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Common functions for other stdnum modules."""
+"""Common utility functions for other stdnum modules.
+
+This module is meant for internal use by stdnum modules and is not
+guaranteed to remain stable and as such not part of the public API of
+stdnum.
+"""
 
 import pkgutil
 

Modified: python-stdnum/stdnum/verhoeff.py
==============================================================================
--- python-stdnum/stdnum/verhoeff.py    Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/verhoeff.py    Sun Feb 26 12:10:38 2012        (r165)
@@ -17,12 +17,14 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for calculation and verifying the checksum of a number
-using the Verhoeff algorithm.
+"""The Verhoeff algorithm.
 
-Validation can be done with is_valid() which validates that the
-calculated checksum is 0. A valid number can be made by calculating
-the check digit and appending it.
+The Verhoeff algorithm uses two tables for permutations and
+multiplications to calculate a checksum.
+
+Validation can be done with is_valid() which validates that the calculated
+checksum is 0. A valid number can be made by calculating the check digit
+and appending it.
 
 >>> is_valid('1234')
 False
--- python-stdnum/stdnum/fr/siren.py    Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/fr/siren.py    Sun Feb 26 12:10:38 2012        (r165)
@@ -18,8 +18,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling French SIREN (Système d’Identification du
-Répertoire des Entreprises) numbers, used to identify French companies.
+"""SIREN (a French company identification number).
+
+The SIREN (Système d'Identification du Répertoire des Entreprises) is a 9
+digit number used to identify French companies. The Luhn checksum is used
+to validate the numbers.
 
 >>> compact('552 008 443')
 '552008443'

Modified: python-stdnum/stdnum/fr/tva.py
==============================================================================
--- python-stdnum/stdnum/gr/vat.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/gr/vat.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,8 +18,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Greek VAT (Foros Prostithemenis Aksias, FPA, ΦΠΑ)
-numbers.
+"""FPA, ΦΠΑ (Foros Prostithemenis Aksias, the Greek VAT number).
+
+The FPA (Foros Prostithemenis Aksias, ΦΠΑ) is used for VAT purposes. It is
+a 9-digit number with a simple checksum.
 
 >>> compact('GR 23456783')
 '023456783'

Modified: python-stdnum/stdnum/grid.py
==============================================================================
--- python-stdnum/stdnum/ismn.py        Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/ismn.py        Sun Feb 26 12:10:38 2012        (r165)
@@ -17,8 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling ISMNs (International Standard Music Number). This
-module handles both numbers in the 10-digit 13-digit format.
+"""ISMN (International Standard Music Number).
+
+The ISMN (International Standard Music Number) is used to identify sheet
+music. This module handles both numbers in the 10-digit 13-digit format.
 
 >>> is_valid('979-0-3452-4680-5')
 True
@@ -49,8 +51,8 @@
 
 
 def ismn_type(number):
-    """Check the type of ISMN number passed and return 'ISMN13', 'ISMN10' or 
None (for
-    invalid)."""
+    """Check the type of ISMN number passed and return 'ISMN13', 'ISMN10'
+    or None (for invalid)."""
     try:
         number = compact(number)
     except:

Modified: python-stdnum/stdnum/iso7064/__init__.py
==============================================================================
--- python-stdnum/stdnum/iso7064/__init__.py    Sat Feb 25 22:06:09 2012        
(r164)
+++ python-stdnum/stdnum/iso7064/__init__.py    Sun Feb 26 12:10:38 2012        
(r165)
@@ -17,8 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Package containing modules for calculation and verification using a
-number of the ISO 7064 algorithms.
+"""Collection of the ISO 7064 algorithms.
+
+This package provides a number of modules for calculation and verification
+of numbers using collection of ISO 7064 algorithms.
 
 Note that these functions were not implemented using the ISO text itself
 because the text is not available for free. These functions were

Modified: python-stdnum/stdnum/iso7064/mod_11_10.py
==============================================================================
--- python-stdnum/stdnum/iso7064/mod_11_10.py   Sat Feb 25 22:06:09 2012        
(r164)
+++ python-stdnum/stdnum/iso7064/mod_11_10.py   Sun Feb 26 12:10:38 2012        
(r165)
@@ -17,12 +17,17 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for calculation and verifying the checksum of a number
-using the ISO 7064 Mod 11, 10 algorithm.
+"""The ISO 7064 Mod 11, 10 algorithm.
+
+The Mod 11, 10 algorithm uses a number of calculations modulo 11 and 10 to
+determine a checksum.
 
 Validation can be done with is_valid(). A valid number can be made by
 calculating the check digit and appending it.
 
+For an module that can do generic Mod x+1, x calculations see the
+stdnum.iso7064.mod_37_36 module.
+
 >>> calc_check_digit('79462')
 '3'
 >>> is_valid('794623')
@@ -35,7 +40,7 @@
 
 
 def checksum(number):
-    """Calculate the checksum."""
+    """Calculate the checksum. A valid number should have a checksum of 1."""
     check = 5
     for n in number:
         check = (((check or 10) * 2) % 11 + int(n)) % 10

Modified: python-stdnum/stdnum/iso7064/mod_11_2.py
==============================================================================
--- python-stdnum/stdnum/iso7064/mod_11_2.py    Sat Feb 25 22:06:09 2012        
(r164)
+++ python-stdnum/stdnum/iso7064/mod_11_2.py    Sun Feb 26 12:10:38 2012        
(r165)
@@ -17,8 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for calculation and verifying the checksum of a number
-using the ISO 7064 Mod 11, 2 algorithm.
+"""The ISO 7064 Mod 11, 2 algorithm.
+
+The Mod 11, 2 algorithm is a simple module 11 checksum where the check
+digit can be an X to make the number valid.
 
 Validation can be done with is_valid(). A valid number can be made by
 calculating the check digit and appending it.
@@ -37,7 +39,7 @@
 
 
 def checksum(number):
-    """Calculate the checksum."""
+    """Calculate the checksum. A valid number should have a checksum of 1."""
     check = 0
     for n in number:
         check = (2 * check + int(10 if n == 'X' else n)) % 11

Modified: python-stdnum/stdnum/iso7064/mod_37_2.py
==============================================================================
--- python-stdnum/stdnum/iso7064/mod_37_2.py    Sat Feb 25 22:06:09 2012        
(r164)
+++ python-stdnum/stdnum/iso7064/mod_37_2.py    Sun Feb 26 12:10:38 2012        
(r165)
@@ -17,8 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for calculation and verifying the checksum of a number
-using the ISO 7064 Mod 37, 2 algorithm.
+"""The ISO 7064 Mod 37, 2 algorithm.
+
+The Mod 37, 2 checksum can be used for alphanumeric numbers and the check
+digit may also be numeric, a letter or '*'.
 
 Validation can be done with is_valid(). A valid number can be made by
 calculating the check digit and appending it.
@@ -31,7 +33,7 @@
 1
 
 By changing the alphabet this can be turned into any Mod x, 2
-algorithm. For example Mod 10, 2:
+algorithm. For example Mod 11, 2:
 
 >>> calc_check_digit('079', alphabet='0123456789X')
 'X'
@@ -43,7 +45,7 @@
 
 
 def checksum(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ*'):
-    """Calculate the checksum."""
+    """Calculate the checksum. A valid number should have a checksum of 1."""
     modulus = len(alphabet)
     check = 0
     for n in number:

Modified: python-stdnum/stdnum/iso7064/mod_37_36.py
==============================================================================
--- python-stdnum/stdnum/iso7064/mod_37_36.py   Sat Feb 25 22:06:09 2012        
(r164)
+++ python-stdnum/stdnum/iso7064/mod_37_36.py   Sun Feb 26 12:10:38 2012        
(r165)
@@ -17,8 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for calculation and verifying the checksum of a number
-using the ISO 7064 Mod 37, 36 algorithm.
+"""The ISO 7064 Mod 37, 36 algorithm.
+
+The Mod 37, 36 algorithm uses an alphanumeric check digit and the number
+itself may also contain letters.
 
 Validation can be done with is_valid(). A valid number can be made by
 calculating the check digit and appending it.
@@ -41,7 +43,7 @@
 
 
 def checksum(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'):
-    """Calculate the checksum."""
+    """Calculate the checksum. A valid number should have a checksum of 1."""
     modulus = len(alphabet)
     check = modulus // 2
     for n in number:

Modified: python-stdnum/stdnum/iso7064/mod_97_10.py
==============================================================================
--- python-stdnum/stdnum/iso7064/mod_97_10.py   Sat Feb 25 22:06:09 2012        
(r164)
+++ python-stdnum/stdnum/iso7064/mod_97_10.py   Sun Feb 26 12:10:38 2012        
(r165)
@@ -17,8 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for calculation and verifying the check digits of a number
-using the ISO 7064 Mod 97, 10 algorithm.
+"""The ISO 7064 Mod 97, 10 algorithm.
+
+The Mod 97, 10 algorithm evaluates the whole number as an integer which is
+valid if the number modulo 97 is 1. As such it has two check digits.
 
 Validation can be done with is_valid(). A valid number can be made by
 calculating the check digits and appending them.
@@ -38,12 +40,12 @@
 
 
 def checksum(number):
-    """Calculate the checksum."""
+    """Calculate the checksum. A valid number should have a checksum of 1."""
     return int(number) % 97
 
 
 def calc_check_digits(number):
     """With the provided number, calculate the extra digit that should be
     appended to make it a valid number."""
     return '%02d' % ((98 - 100 * checksum(number)) % 97)
 
@@ -38,12 +40,12 @@
 
 def calc_check_digits(number):
-    """With the provided number, calculate the extra digit that should be
+    """With the provided number, calculate the extra digits that should be
     appended to make it a valid number."""
     return '%02d' % ((98 - 100 * checksum(number)) % 97)

Modified: python-stdnum/stdnum/issn.py
==============================================================================
--- python-stdnum/stdnum/issn.py        Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/issn.py        Sun Feb 26 12:10:38 2012        (r165)
@@ -17,8 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling ISSNs (International Standard Serial Number), the
-standard code to identify serial publications.
+"""ISSN (International Standard Serial Number).
+
+The ISSN (International Standard Serial Number) is the standard code to
+identify periodical publications. It has a checksum similar to ISBN-10.
 
 >>> is_valid('0024-9319')
 True
@@ -42,7 +44,7 @@
     return clean(number, ' -').strip().upper()
 
 
-def _calc_check_digit(number):
+def calc_check_digit(number):
     """Calculate the ISSN check digit for 10-digit numbers. The number passed
     should not have the check bit included."""
     check = (11 - sum((8 - i) * int(n)
@@ -59,7 +61,7 @@
         return False
     return len(number) == 8 and \
            number[:-1].isdigit() and \
-           _calc_check_digit(number[:-1]) == number[-1]
+           calc_check_digit(number[:-1]) == number[-1]
 
 
 def format(number):

Modified: python-stdnum/stdnum/it/iva.py
==============================================================================
--- python-stdnum/stdnum/nl/btw.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/nl/btw.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -17,7 +17,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Dutch VAT (BTW) numbers.
+"""BTW-nummer (Omzetbelastingnummer, the Dutch VAT number).
+
+The BTW-nummer is the Dutch number for VAT. It consists of a RSIN or BSN
+followed by a B and two digits that identify the unit within the
+organisation (usually 01).
 
 >>> is_valid('004495445B01')
 True

Modified: python-stdnum/stdnum/nl/onderwijsnummer.py
==============================================================================
--- python-stdnum/stdnum/nl/onderwijsnummer.py  Sat Feb 25 22:06:09 2012        
(r164)
+++ python-stdnum/stdnum/nl/onderwijsnummer.py  Sun Feb 26 12:10:38 2012        
(r165)
@@ -17,9 +17,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling onderwijsnummers (school number), very similar to
-the BSN (Dutch national identification number) but for students without a
-BSN.
+"""Onderwijsnummer (Dutch school number).
+
+The onderwijsnummers (school number) is very similar to the BSN (Dutch
+national identification number) but for students without a BSN. It uses a
+small variation of the BSN checksum.
 
 >>> is_valid('101222331')
 True
@@ -32,6 +34,9 @@
 from stdnum.nl.bsn import compact, checksum
 
 
+__all__ = ['compact', 'is_valid']
+
+
 def is_valid(number):
     """Checks to see if the number provided is a valid onderwijsnummer.
     This checks the length and whether the check digit is correct and

Modified: python-stdnum/stdnum/numdb.py
==============================================================================
--- python-stdnum/stdnum/pt/nif.py      Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/pt/nif.py      Sun Feb 26 12:10:38 2012        (r165)
@@ -18,8 +18,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Portuguese NIF (Número de identificação fiscal,
-NIPC, Número de Identificação de Pessoa Colectiva, VAT) numbers.
+"""NIF (Número de identificação fiscal, Portuguese VAT number).
+
+The NIF (Número de identificação fiscal, NIPC, Número de Identificação de
+Pessoa Colectiva) is used for VAT purposes. It is a 9-digit number with a
+simple checksum.
 
 >>> compact('PT 501 964 843')
 '501964843'

Modified: python-stdnum/stdnum/ro/cf.py
==============================================================================
--- python-stdnum/stdnum/ro/cf.py       Sat Feb 25 22:06:09 2012        (r164)
+++ python-stdnum/stdnum/ro/cf.py       Sun Feb 26 12:10:38 2012        (r165)
@@ -18,10 +18,9 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling Romanian CF (Cod de înregistrare în scopuri de TVA)
-numbers.
+"""CF (Cod de înregistrare în scopuri de TVA, Romanian VAT number).
 
-These numbers can be from 2 to 10 digits long.
+The Romanian CF is used for VAT purposes and can be from 2 to 10 digits long.
 
 >>> compact('RO 185 472 90')
 '18547290'

Modified: python-stdnum/stdnum/ro/cnp.py
==============================================================================
-- 
To unsubscribe send an email to
python-stdnum-commits-unsubscribe@lists.arthurdejong.org or see
http://lists.arthurdejong.org/python-stdnum-commits/